@@ -5,7 +5,11 @@ Cache utilities module - Reusable caching functionality
 from .cache_utils import (
     generate_cache_id,
     get_or_set_cache,
-    invalidate_cache_keys
+    invalidate_cache_keys,
+    build_cache_key,
+    cache_response,
+    invalidate_tag,
+    cache_factory,
 )
 
 # Re-export core utilities for convenience in this domain
@@ -14,8 +18,12 @@ from ..core.serialization import datetime_serializer
 
 __all__ = [
     "generate_cache_id",
-    "datetime_serializer", 
+    "datetime_serializer",
     "get_or_set_cache",
     "invalidate_cache_keys",
-    "normalize"
-] 
\ No newline at end of file
+    "normalize",
+    "build_cache_key",
+    "cache_response",
+    "invalidate_tag",
+    "cache_factory",
+]
